@@ -1,5 +1,5 @@
 from connectmon.logger import get_logger
-from connectmon.models import Connector, Task
+from connectmon.models import Connector, Task, Message
 
 from typing import List
 import requests
@@ -20,6 +20,9 @@ class API:
         self.url = url
         self.logger = get_logger(self.__class__.__name__)
 
+        if not self.is_reachable():
+            raise Exception("Cluster is not reachable")
+
     def __str__(self) -> str:
         return f"API(url={self.url})"
 
@@ -30,12 +33,16 @@ class API:
         """Check if the Connect cluster is reachable
 
         Returns:
-            bool: True if the cluster is reachable, False otherwise"""
-        self.logger.debug(f"Checking health of {self.url}")
+            bool: True if the cluster is reachable, False otherwise
+        """
+        is_reachable = requests.get(f"{self.url}/").status_code == 200
+        self.logger.info(
+            f"Checking reachability of {self.url} - {'cluster is reachable' if is_reachable else 'cluster is not reachable'}"
+        )
         return requests.get(f"{self.url}/").status_code == 200
 
-    def get_all_connector_status(self) -> List[Connector]:
-        """Get the status of all connectors
+    def get_all_connectors(self) -> List[Connector]:
+        """Get all connectors
 
         Returns:
             List[Connector]: A list of Connector objects
@@ -74,7 +81,7 @@ class API:
         Returns:
             requests.Response: The response from the API
         """
-        self.logger.debug(f"Resuming {connector.name}")
+        self.logger.info(f"Resuming {connector.name}")
         return requests.put(f"{self.url}/connectors/{connector.name}/resume")
 
     def restart_connector(self, connector: Connector) -> requests.Response:
@@ -86,7 +93,7 @@ class API:
         Returns:
             requests.Response: The response from the API
         """
-        self.logger.debug(f"Restarting {connector.name}")
+        self.logger.info(f"Restarting {connector.name}")
         return requests.post(f"{self.url}/connectors/{connector.name}/restart")
 
     def restart_task(self, connector: Connector, task: Task) -> requests.Response:
@@ -99,21 +106,21 @@ class API:
         Returns:
             requests.Response: The response from the API
         """
-        self.logger.debug(f"Restarting task {task.id} for {connector.name}")
+        self.logger.info(f"Restarting task {task.id} for {connector.name}")
         return requests.post(
             f"{self.url}/connectors/{connector.name}/tasks/{task.id}/restart"
         )
 
     def restart_failed_connectors_if_any(
         self, connectors: List[Connector]
-    ) -> List[dict]:
+    ) -> List[Message]:
         """Restart failed connectors and tasks
 
         Args:
             connectors (List[Connector]): A list of Connector objects
 
         Returns:
-            List[dict]: A list of errors and warning messages
+            List[Message]: A list of errors and warning messages
         """
         errors_and_warnings = []
 
@@ -122,23 +129,32 @@ class API:
 
             if not connector.is_running:
                 if connector.is_paused:
-                    msg = {"level": "warn", "message": f"Resuming {connector.name}"}
-                    self.logger.warn(msg["message"])
+                    msg = Message(
+                        sender=connector.name,
+                        level="warn",
+                        message=f"Resuming {connector.name}",
+                    )
+                    self.logger.warn(msg.message)
                     errors_and_warnings.append(msg)
                     self.resume_connector(connector)
                 else:
-                    msg = {"level": "error", "message": f"Restarting {connector.name}"}
-                    self.logger.error(msg["message"])
+                    msg = Message(
+                        sender=connector.name,
+                        level="error",
+                        message=f"Restarting {connector.name}",
+                    )
+                    self.logger.error(msg.message)
                     errors_and_warnings.append(msg)
                     self.restart_connector(connector)
 
             for task in connector.tasks:
                 if not task.is_running:
-                    msg = {
-                        "level": "error",
-                        "message": f"Restarting task {task.id} for {connector.name}",
-                    }
-                    self.logger.error(msg["message"])
+                    msg = Message(
+                        sender=connector.name,
+                        level="error",
+                        message=f"Restarting task {task.id} for {connector.name}",
+                    )
+                    self.logger.error(msg.message)
                     errors_and_warnings.append(msg)
                     self.restart_task(connector, task)
 
@@ -151,4 +167,4 @@ if __name__ == "__main__":
     api = API(env.CONNECT_URL)
     print(api.is_reachable())
     print(api.get_connector_status("my-file-sink"))
-    print(api.get_all_connector_status())
+    print(api.get_all_connectors())
